searchNodes=[{"ref":"Unicode.Set.html","title":"Unicode.Set","type":"module","doc":"Usage The primary api is the macro Unicode.Set.match?/2 that returns a boolean based upon whether a given codepoint matches a unicode set. Function guards This is helpful in defining function guards. For example: defmodule Guards do require Unicode.Set # Define a guard that checks if a codepoint is a unicode digit defguard digit?(x) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) end defmodule MyModule do require Guards # Define a function using the previously defined guard def my_function(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Guards.digit?(x) do IO.puts &quot;Its a digit!&quot; end # Define a guard directly on the function def my_other_function_(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) do IO.puts &quot;Its also a digit!&quot; end end Generating compiled patterns for String matching String.split/3 and String.replace/3 allow for patterns and compiled patterns to be used with compiled patterns being the more performant approach. Unicode Set supports the generation of patterns and compiled patterns: iex&gt; pattern = Unicode.Set.compile_pattern &quot;[[:digit:]]&quot; iex&gt; list = String.split(&quot;abc1def2ghi3jkl&quot;, pattern) [&quot;abc&quot;, &quot;def&quot;, &quot;ghi&quot;, &quot;jkl&quot;] Generating NimbleParsec ranges The parser generator nimble_parsec allows a list of codepoint ranges as parameters to several combinators. Unicode Set can generate such ranges: iex&gt; Unicode.Set.utf8_char(&quot;[[^abcd][mnb]]&quot;) [{:not, 97}, {:not, 98}, {:not, 99}, {:not, 100}, 98, 109, 110] This can be used as shown in the following example: defmodule MyCombinators do import NimbleParsec def unicode_digit do digit_list = Unicode.Set.utf8_char(&quot;[[:digit:]]&quot;) utf8_char(digit_list) |&gt; label(&quot;a digit in any Unicode script&quot;) end end Other Examples These examples show how to combine sets (union, difference and intersection) to deliver a flexible targeting of the required match. # The character &quot;๓&quot; is the thai digit `1` iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]]&quot; true # Set operations allow union, insersection and difference # This example matches on digits, but not the Thai script iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]-[:thai:]]&quot; false Compile time parsing As much work as possible is done at compile time in order to deliver good performance. The macro Unicode.Set.match?/2 parses the unicode set, expands the require codepoints and generates guard clauses at compile time. The resulting code is a simple set of boolean operators that executes quickly at runtime. Introduction to Unicode Sets Here are a few examples of sets. Although elements of the syntax appear similar to regular expressions, unicode sets only expresses one or more ranges of unicode codepoints. PatternDescription [a-z]The lower case letters a through z [abc123]The six characters a,b,c,1,2 and 3 [\\p{Letter}]All characters with the Unicode General Category of Letter String Values In addition to being a set of characters (of Unicode code points), a UnicodeSet may also contain string values. Conceptually, the UnicodeSet is always a set of strings, not a set of characters, although in many common use cases the strings are all of length one, which reduces to being a set of characters. This concept can be confusing when first encountered, probably because similar set constructs from other environments (regular expressions) can only contain characters. Unicode Set Patterns Patterns are a series of characters bounded by square brackets that contain lists of characters and Unicode property sets. Lists are a sequence of characters that may have ranges indicated by a &#39;-&#39; between two characters, as in &quot;a-z&quot;. The sequence specifies the range of all characters from the left to the right, in Unicode order. For example, [a c d-f m] is equivalent to [a c d e f m]. Whitespace can be freely used for clarity as [a c d-f m] means the same as [acd-fm]. Unicode property sets are specified by a Unicode property, such as [:Letter:]. For a list of supported properties, see the Properties chapter. For details on the use of short vs. long property and property value names, see the end of this section. The syntax for specifying the property names is an extension of either POSIX or Perl syntax with the addition of =value. For example, you can match letters by using the POSIX syntax [:Letter:], or by using the Perl-style syntax \\p{Letter}. The type can be omitted for the Category and Script properties, but is required for other properties. The table below shows the two kinds of syntax: POSIX and Perl style. Also, the table shows the &quot;Negative&quot;, which is a property that excludes all characters of a given kind. For example, [:^Letter:] matches all characters that are not [:Letter:]. StylePositiveNegative POSIX-style Syntax[:type=value:][:^type=value:] Perl-style Syntax\\p{type=value}\\P{type=value} These following low-level lists or properties then can be freely combined with the normal set operations (union, inverse, difference, and intersection): ExampleMeaning A B [[:letter:] [:number:]]To union two sets A and B, simply concatenate them A &amp; B [[:letter:] &amp; [a-z]]To intersect two sets A and B, use the &#39;&amp;&#39; operator. A - B [[:letter:] - [a-z]]To take the set-difference of two sets A and B, use the &#39;-&#39; operator. [^A] [^a-z]To invert a set A, place a ^``` immediately after the opening[. Note that the complement only affects code points, not string values. In any other location, the^` does not have a special meaning. Precedence The binary operators of union, intersection, and set-difference have equal precedence and bind left-to-right. Thus the following are equivalent: [[:letter:] - [a-z] [:number:] &amp; [\\u0100-\\u01FF]] [[[[[:letter:] - [a-z]] [:number:]] &amp; [\\u0100-\\u01FF]] Another example is that the set [[ace][bdf] - [abc][def]] is not the empty set, but instead the set [def]. That is because the syntax corresponds to the following UnicodeSet operations: start with [ace] union [bdf] -- we now have [abcdef] subtract [abc] -- we now have [def] union [def] -- no effect, we still have [def] This only really matters where there are the difference and intersection operations, as the union operation is commutative. To make sure that the - is the main operator, add brackets to group the operations as desired, such as [[ace][bdf] - [[abc][def]]]. Another caveat with the &amp; and - operators is that they operate between sets. That is, they must be immediately preceded and immediately followed by a set. For example, the pattern [[:Lu:]-A] is illegal, since it is interpreted as the set [:Lu:] followed by the incomplete range -A. To specify the set of uppercase letters except for A, enclose the A in a set: [[:Lu:]-[A]]. Examples [a] The set containing &#39;a&#39; [a-z] The set containing &#39;a&#39; through &#39;z&#39; and all letters in between, in Unicode order [^a-z] The set containing all characters but &#39;a&#39; through &#39;z&#39;, that is, U+0000 through &#39;a&#39;-1 and &#39;z&#39;+1 through U+FFFF [[pat1][pat2]] The union of sets specified by pat1 and pat2 [[pat1]&amp;[pat2]] The intersection of sets specified by pat1 and pat2 [[pat1]-[pat2]] The asymmetric difference of sets specified by pat1 and pat2 [:Lu:] The set of characters belonging to the given Unicode category; in this case, Unicode uppercase letters. The long form for this is [:UppercaseLetter:]. [:L:] The set of characters belonging to all Unicode categories starting with &#39;L&#39;, that is, [[:Lu:][:Ll:][:Lt:][:Lm:][:Lo:]]. The long form for this is [:Letter:]. String Values in Sets String values are enclosed in {curly brackets}. Set expressionDescription [abc{def}]A set containing four members, the single characters a, b and c, and the string “def” [{abc}{def}]A set containing two members, the string “abc” and the string “def”. [{a}{b}{c}][abc]These two sets are equivalent. Each contains three items, the three individual characters a, b and c. A {string} containing a single character is equivalent to that same character specified in any other way. Character Quoting and Escaping in Unicode Set Patterns Single Quote Two single quotes represents a single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). It is taken as literal text (special characters become non-special). These quoting conventions for ICU UnicodeSets differ from those of regular expression character set expressions. In regular expressions, single quotes have no special meaning and are treated like any other literal character. Backslash Escapes Outside of single quotes, certain backslashed characters have special meaning. Note that these are escapes processed by Unicode Set (this library) and therefore require \\\\\\\\ to be entered as a prefix. Elixir also provides similar escapes as native part of its string processing and Elixir&#39;s escapes are to be preferred where possible. EscapeDescription \\uhhhhExactly 4 hex digits; h in [0-9A-Fa-f] \\UhhhhhhhhExactly 8 hex digits \\xhh1-2 hex digits Certain other escapes are native to Elixir and are applicable in Unicode Sets they are in any Elixir string: EscapeDescription \\aU+0007 (BELL) \\bU+0008 (BACKSPACE) \\tU+0009 (HORIZONTAL TAB) \\nU+000A (LINE FEED) \\vU+000B (VERTICAL TAB) \\fU+000C (FORM FEED) \\rU+000D (CARRIAGE RETURN) \\U+005C (BACKSLASH) \\xDDrepresents a single byte in hexadecimal (such as \\x13) \\uDDDD and \\u{D...}represents a Unicode codepoint in hexadecimal (such as \\u{1F600}) Anything else following a backslash is mapped to itself, except in an environment where it is defined to have some special meaning. For example, \\p{Lu} is the set of uppercase letters in a Unicode Set. Any character formed as the result of a backslash escape loses any special meaning and is treated as a literal. In particular, note that \\u and \\U escapes create literal characters. Whitespace Whitespace (as defined by the specification) is ignored unless it is quoted or backslashed. Property Values The following property value variants are recognized: FormatExampleDescription shortLuomits the type (used to prevent ambiguity and only allowed with the Category and Script properties) mediumgc=Luuses an abbreviated type and value longGeneral_Category=Uppercase_Letteruses a full type and value If the type or value is omitted, then the equals sign is also omitted. The short style is only used for Category and Script properties because these properties are very common and their omission is unambiguous. In actual practice, you can mix type names and values that are omitted, abbreviated, or full. For example, if Category=Unassigned you could use what is in the table explicitly, \\p{gc=Unassigned}, \\p{Category=Cn}, or \\p{Unassigned}. When these are processed, case and whitespace are ignored so you may use them for clarity, if desired. For example, \\p{Category = Uppercase Letter} or \\p{Category = uppercase letter}."},{"ref":"Unicode.Set.html#compile_pattern/1","title":"Unicode.Set.compile_pattern/1","type":"function","doc":""},{"ref":"Unicode.Set.html#match?/2","title":"Unicode.Set.match?/2","type":"macro","doc":"Returns a boolean based upon whether var matches the provided unicode_set. Arguments var is any integer variable (since codepoints are integers) unicode_set is a binary representation of a unicode set. An exception will be raised if unicode_set is not a compile time binary Returns true or false Examples Unicode.match?/2 can be used in as defguard argument. For example: #=&gt; defguard is_lower(codepoint) when Unicode.Set.match?(codepoint, &quot;[[:Lu:]]&quot;) Or as a guard clause itself: #=&gt; def my_function(&lt;&lt; codepoint :: utf8, _rest :: binary&gt;&gt;) when Unicode.Set.match?(codepoint, &quot;[[:Lu:]]&quot;)"},{"ref":"Unicode.Set.html#parse/2","title":"Unicode.Set.parse/2","type":"function","doc":"Parses a Unicode Set binary into an internal AST-like representation Example iex&gt; Unicode.Set.parse(&quot;[[:Zs:]]&quot;) {:ok, [ in: [ {32, 32}, {160, 160}, {5760, 5760}, {8192, 8202}, {8239, 8239}, {8287, 8287}, {12288, 12288} ] ], &quot;&quot;, %{}, {1, 0}, 8}"},{"ref":"Unicode.Set.html#parse!/1","title":"Unicode.Set.parse!/1","type":"function","doc":""},{"ref":"Unicode.Set.html#pattern/1","title":"Unicode.Set.pattern/1","type":"function","doc":""},{"ref":"Unicode.Set.html#utf8_char/1","title":"Unicode.Set.utf8_char/1","type":"function","doc":""},{"ref":"Unicode.Set.Operation.html","title":"Unicode.Set.Operation","type":"module","doc":"Functions to operate on Unicode sets: Intersection Difference Union"},{"ref":"Unicode.Set.Operation.html#combine/1","title":"Unicode.Set.Operation.combine/1","type":"function","doc":"Combines all the ranges into a single list This function is called iff the Unicode Sets are formed by unions only. If the set operations of intersection or difference are present then the ranges will need to be expanded via expand/1."},{"ref":"Unicode.Set.Operation.html#difference/2","title":"Unicode.Set.Operation.difference/2","type":"function","doc":"Removes one list of 2-tuples representing Unicode codepoints from another. Returns the first list of codepoint ranges minus the codepoints in the second list."},{"ref":"Unicode.Set.Operation.html#expand/1","title":"Unicode.Set.Operation.expand/1","type":"function","doc":"Expands all sets, properties and ranges to a list of 2-tuples expressing a range of codepoints"},{"ref":"Unicode.Set.Operation.html#has_difference_or_intersection?/1","title":"Unicode.Set.Operation.has_difference_or_intersection?/1","type":"function","doc":"Returns a boolean indicating whether the given AST includes set operations intersection or difference. When these operations exist then all ranges - including ^ ranges needs to be expanded. If there are no intersections or differences then the ^ ranges can be directly translated to guard clauses or a list of elixir ranges."},{"ref":"Unicode.Set.Operation.html#intersect/2","title":"Unicode.Set.Operation.intersect/2","type":"function","doc":"Returns the intersection of two lists of 2-tuples representing codepoint ranges. The result is a single list of codepoint ranges that represents the common codepoints in the two lists."},{"ref":"Unicode.Set.Operation.html#invert/1","title":"Unicode.Set.Operation.invert/1","type":"function","doc":"Returns a list of 2-tuples representing codepoint ranges that are the full set of Unicode ranges minus the ranges for a given property."},{"ref":"Unicode.Set.Operation.html#prewalk/2","title":"Unicode.Set.Operation.prewalk/2","type":"function","doc":"Prewalks the expanded AST from a parsed Unicode Set invoking a function on each codepoint range in the set."},{"ref":"Unicode.Set.Operation.html#prewalk/3","title":"Unicode.Set.Operation.prewalk/3","type":"function","doc":""},{"ref":"Unicode.Set.Operation.html#symmetric_difference/2","title":"Unicode.Set.Operation.symmetric_difference/2","type":"function","doc":"Returns the difference of two lists of 2-tuples representing codepoint ranges. The result is a single list of codepoint ranges that represents the codepoints that are in either of the two lists but not both."},{"ref":"Unicode.Set.Operation.html#union/2","title":"Unicode.Set.Operation.union/2","type":"function","doc":"Merges two lists of 2-tuples representing ranges of codepoints. The result is a single list of 2-tuple codepoint ranges that includes all codepoint from the two lists. It is assumed that both lists are sorted prior to merging."},{"ref":"readme.html","title":"Unicode Set","type":"extras","doc":"Unicode Set A Unicode Set is a representation of a set of Unicode characters or character strings. The contents of that set are specified by patterns or by building them programmatically. This library implements parsing of unicode sets, resolving them to a list of codepoints and matching a given codepoint to that list. This is all consoldited into a single primary macro, Unicode.Set.match?/2. The implementation conforms closely to the Unicode Set specification but currently omits support for the \\N{codepoint_name} syntax."},{"ref":"readme.html#usage","title":"Unicode Set - Usage","type":"extras","doc":"The primary api is the macro Unicode.Set.match?/2 that returns a boolean based upon whether a given codepoint matches a unicode set. Function guards This is helpful in defining function guards. For example: defmodule Guards do require Unicode.Set # Define a guard that checks if a codepoint is a unicode digit defguard digit?(x) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) end defmodule MyModule do require Guards # Define a function using the previously defined guard def my_function(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Guards.digit?(x) do IO.puts &quot;Its a digit!&quot; end # Define a guard directly on the function def my_other_function_(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) do IO.puts &quot;Its also a digit!&quot; end end Generating compiled patterns for String matching String.split/3 and String.replace/3 allow for patterns and compiled patterns to be used with compiled patterns being the more performant approach. Unicode Set supports the generation of patterns and compiled patterns: iex&gt; pattern = Unicode.Set.compile_pattern &quot;[[:digit:]]&quot; iex&gt; list = String.split(&quot;abc1def2ghi3jkl&quot;, pattern) [&quot;abc&quot;, &quot;def&quot;, &quot;ghi&quot;, &quot;jkl&quot;] Generating NimbleParsec ranges The parser generator nimble_parsec allows a list of codepoint ranges as parameters to several combinators. Unicode Set can generate such ranges: iex&gt; Unicode.Set.utf8_char(&quot;[[^abcd][mnb]]&quot;) [{:not, 97}, {:not, 98}, {:not, 99}, {:not, 100}, 98, 109, 110] This can be used as shown in the following example: defmodule MyCombinators do import NimbleParsec def unicode_digit do digit_list = Unicode.Set.utf8_char(&quot;[[:digit:]]&quot;) utf8_char(digit_list) |&gt; label(&quot;a digit in any Unicode script&quot;) end end Other Examples These examples show how to combine sets (union, difference and intersection) to deliver a flexible targeting of the required match. # The character &quot;๓&quot; is the thai digit `1` iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]]&quot; true # Set operations allow union, insersection and difference # This example matches on digits, but not the Thai script iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]-[:thai:]]&quot; false Compile time parsing As much work as possible is done at compile time in order to deliver good performance. The macro Unicode.Set.match?/2 parses the unicode set, expands the require codepoints and generates guard clauses at compile time. The resulting code is a simple set of boolean operators that executes quickly at runtime."},{"ref":"readme.html#introduction-to-unicode-sets","title":"Unicode Set - Introduction to Unicode Sets","type":"extras","doc":"Here are a few examples of sets. Although elements of the syntax appear similar to regular expressions, unicode sets only expresses one or more ranges of unicode codepoints. PatternDescription [a-z]The lower case letters a through z [abc123]The six characters a,b,c,1,2 and 3 [\\p{Letter}]All characters with the Unicode General Category of Letter String Values In addition to being a set of characters (of Unicode code points), a UnicodeSet may also contain string values. Conceptually, the UnicodeSet is always a set of strings, not a set of characters, although in many common use cases the strings are all of length one, which reduces to being a set of characters. This concept can be confusing when first encountered, probably because similar set constructs from other environments (regular expressions) can only contain characters."},{"ref":"readme.html#unicode-set-patterns","title":"Unicode Set - Unicode Set Patterns","type":"extras","doc":"Patterns are a series of characters bounded by square brackets that contain lists of characters and Unicode property sets. Lists are a sequence of characters that may have ranges indicated by a &#39;-&#39; between two characters, as in &quot;a-z&quot;. The sequence specifies the range of all characters from the left to the right, in Unicode order. For example, [a c d-f m] is equivalent to [a c d e f m]. Whitespace can be freely used for clarity as [a c d-f m] means the same as [acd-fm]. Unicode property sets are specified by a Unicode property, such as [:Letter:]. For a list of supported properties, see the Properties chapter. For details on the use of short vs. long property and property value names, see the end of this section. The syntax for specifying the property names is an extension of either POSIX or Perl syntax with the addition of =value. For example, you can match letters by using the POSIX syntax [:Letter:], or by using the Perl-style syntax \\p{Letter}. The type can be omitted for the Category and Script properties, but is required for other properties. The table below shows the two kinds of syntax: POSIX and Perl style. Also, the table shows the &quot;Negative&quot;, which is a property that excludes all characters of a given kind. For example, [:^Letter:] matches all characters that are not [:Letter:]. StylePositiveNegative POSIX-style Syntax[:type=value:][:^type=value:] Perl-style Syntax\\p{type=value}\\P{type=value} These following low-level lists or properties then can be freely combined with the normal set operations (union, inverse, difference, and intersection): ExampleMeaning A B [[:letter:] [:number:]]To union two sets A and B, simply concatenate them A &amp; B [[:letter:] &amp; [a-z]]To intersect two sets A and B, use the &#39;&amp;&#39; operator. A - B [[:letter:] - [a-z]]To take the set-difference of two sets A and B, use the &#39;-&#39; operator. [^A] [^a-z]To invert a set A, place a ^``` immediately after the opening[. Note that the complement only affects code points, not string values. In any other location, the^` does not have a special meaning."},{"ref":"readme.html#precedence","title":"Unicode Set - Precedence","type":"extras","doc":"The binary operators of union, intersection, and set-difference have equal precedence and bind left-to-right. Thus the following are equivalent: [[:letter:] - [a-z] [:number:] &amp; [\\u0100-\\u01FF]] [[[[[:letter:] - [a-z]] [:number:]] &amp; [\\u0100-\\u01FF]] Another example is that the set [[ace][bdf] - [abc][def]] is not the empty set, but instead the set [def]. That is because the syntax corresponds to the following UnicodeSet operations: start with [ace] union [bdf] -- we now have [abcdef] subtract [abc] -- we now have [def] union [def] -- no effect, we still have [def] This only really matters where there are the difference and intersection operations, as the union operation is commutative. To make sure that the - is the main operator, add brackets to group the operations as desired, such as [[ace][bdf] - [[abc][def]]]. Another caveat with the &amp; and - operators is that they operate between sets. That is, they must be immediately preceded and immediately followed by a set. For example, the pattern [[:Lu:]-A] is illegal, since it is interpreted as the set [:Lu:] followed by the incomplete range -A. To specify the set of uppercase letters except for A, enclose the A in a set: [[:Lu:]-[A]]."},{"ref":"readme.html#examples","title":"Unicode Set - Examples","type":"extras","doc":"[a] The set containing &#39;a&#39; [a-z] The set containing &#39;a&#39; through &#39;z&#39; and all letters in between, in Unicode order [^a-z] The set containing all characters but &#39;a&#39; through &#39;z&#39;, that is, U+0000 through &#39;a&#39;-1 and &#39;z&#39;+1 through U+FFFF [[pat1][pat2]] The union of sets specified by pat1 and pat2 [[pat1]&amp;[pat2]] The intersection of sets specified by pat1 and pat2 [[pat1]-[pat2]] The asymmetric difference of sets specified by pat1 and pat2 [:Lu:] The set of characters belonging to the given Unicode category; in this case, Unicode uppercase letters. The long form for this is [:UppercaseLetter:]. [:L:] The set of characters belonging to all Unicode categories starting with &#39;L&#39;, that is, [[:Lu:][:Ll:][:Lt:][:Lm:][:Lo:]]. The long form for this is [:Letter:]."},{"ref":"readme.html#string-values-in-sets","title":"Unicode Set - String Values in Sets","type":"extras","doc":"String values are enclosed in {curly brackets}. Set expressionDescription [abc{def}]A set containing four members, the single characters a, b and c, and the string “def” [{abc}{def}]A set containing two members, the string “abc” and the string “def”. [{a}{b}{c}][abc]These two sets are equivalent. Each contains three items, the three individual characters a, b and c. A {string} containing a single character is equivalent to that same character specified in any other way."},{"ref":"readme.html#character-quoting-and-escaping-in-unicode-set-patterns","title":"Unicode Set - Character Quoting and Escaping in Unicode Set Patterns","type":"extras","doc":"Single Quote Two single quotes represents a single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). It is taken as literal text (special characters become non-special). These quoting conventions for ICU UnicodeSets differ from those of regular expression character set expressions. In regular expressions, single quotes have no special meaning and are treated like any other literal character. Backslash Escapes Outside of single quotes, certain backslashed characters have special meaning. Note that these are escapes processed by Unicode Set (this library) and therefore require \\\\\\\\ to be entered as a prefix. Elixir also provides similar escapes as native part of its string processing and Elixir&#39;s escapes are to be preferred where possible. EscapeDescription \\uhhhhExactly 4 hex digits; h in [0-9A-Fa-f] \\UhhhhhhhhExactly 8 hex digits \\xhh1-2 hex digits Certain other escapes are native to Elixir and are applicable in Unicode Sets they are in any Elixir string: EscapeDescription \\aU+0007 (BELL) \\bU+0008 (BACKSPACE) \\tU+0009 (HORIZONTAL TAB) \\nU+000A (LINE FEED) \\vU+000B (VERTICAL TAB) \\fU+000C (FORM FEED) \\rU+000D (CARRIAGE RETURN) \\U+005C (BACKSLASH) \\xDDrepresents a single byte in hexadecimal (such as \\x13) \\uDDDD and \\u{D...}represents a Unicode codepoint in hexadecimal (such as \\u{1F600}) Anything else following a backslash is mapped to itself, except in an environment where it is defined to have some special meaning. For example, \\p{Lu} is the set of uppercase letters in a Unicode Set. Any character formed as the result of a backslash escape loses any special meaning and is treated as a literal. In particular, note that \\u and \\U escapes create literal characters. Whitespace Whitespace (as defined by the specification) is ignored unless it is quoted or backslashed."},{"ref":"readme.html#property-values","title":"Unicode Set - Property Values","type":"extras","doc":"The following property value variants are recognized: FormatExampleDescription shortLuomits the type (used to prevent ambiguity and only allowed with the Category and Script properties) mediumgc=Luuses an abbreviated type and value longGeneral_Category=Uppercase_Letteruses a full type and value If the type or value is omitted, then the equals sign is also omitted. The short style is only used for Category and Script properties because these properties are very common and their omission is unambiguous. In actual practice, you can mix type names and values that are omitted, abbreviated, or full. For example, if Category=Unassigned you could use what is in the table explicitly, \\p{gc=Unassigned}, \\p{Category=Cn}, or \\p{Unassigned}. When these are processed, case and whitespace are ignored so you may use them for clarity, if desired. For example, \\p{Category = Uppercase Letter} or \\p{Category = uppercase letter}."},{"ref":"readme.html#installation","title":"Unicode Set - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding unicode_set to your list of dependencies in mix.exs: def deps do [ {:unicode_set, &quot;~&gt; 0.1.0&quot;} ] end Documentation can be found at https://hexdocs.pm/unicode_set."},{"ref":"license.html","title":"License","type":"extras","doc":"License Copyright 2019 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."},{"ref":"changelog.html","title":"Changelog for Unicode Set v0.2.0","type":"extras","doc":"Changelog for Unicode Set v0.2.0 This is the changelog for Unicode Set v0.2.0 released on November 24th, 2019. For older changelogs please consult the release tag on GitHub Add Unicode.Set.compile_pattern/1 and Unicode.Set.pattern/1 to generate patterns and compiled patterns compatible with String.split/3 and String.replace/3. Add Unicode.Set.utf8_char/1 that generates a list of codepoint ranges compatible with nimble_parsec combinators. Set the README for example usage. Changelog for Unicode Set v0.1.0 This is the changelog for Unicode Set v0.1.0 released on November 23rd, 2019. For older changelogs please consult the release tag on GitHub Initial release."}]